Crate fine_ill_do_it_myself

Crate fine_ill_do_it_myself 

This crate provides the DirSizeTracker struct, which efficiently keeps track of a directory’s total size using filesystem events.

See the list of known problems in the docs of notify.

Re-exports

pub use notify;

Structs

DirSizeTracker
Keeps track of a directory’s total size.
Error
Error that occurs in DirSizeTracker::new or when responding to filesystem events.

Enums

Mode
Specifies the method used for calculating file sizes.