This crate provides the DirSizeTracker struct, which efficiently keeps track of a directory’s total size using filesystem events.
See the list of known problems in the docs of notify.
Re-exports
pub use notify;
Structs
- DirSize
Tracker - Keeps track of a directory’s total size.
- Error
- Error that occurs in
DirSizeTracker::newor when responding to filesystem events.
Enums
- Mode
- Specifies the method used for calculating file sizes.